from charmhelpers.core import hookenv
from charmhelpers.contrib.openstack.context import OSContextGenerator


class RelationContext(OSContextGenerator):
    def __call__(self):
        if not hookenv.relation_ids(self.interface):
            return {}

        ctx = {}
        for rid in hookenv.relation_ids(self.interface):
            for unit in hookenv.related_units(rid):
                reldata = hookenv.relation_get(rid=rid, unit=unit)
                required = set(self.required_keys)
                if set(reldata.keys()) == required:
                    ns = ctx.setdefault(self.interface, {})
                    for k, v in reldata.items():
                        ns[k] = v
                    return ctx

        return {}


class ConfigContext(OSContextGenerator):
    def __call__(self):
        return hookenv.config()


class StaticContext(OSContextGenerator):
    def __init__(self, data):
        self.data = data

    def __call__(self):
        return self.data


class NatsContext(RelationContext):
    interface = 'nats'
    required_keys = ['nats_port', 'nats_host', 'nats_user', 'nats_password']


class RouterContext(RelationContext):
    interface = 'router'
    required_keys = ['domain']
