#!/usr/bin/env python
# vim: et ai ts=4 sw=4:
import os
import sys

from charmhelpers.core import hookenv, host
from charmhelpers.core.hookenv import log, DEBUG
from charmhelpers.contrib.cloudfoundry.common import chownr, run
from charmhelpers.contrib.cloudfoundry import contexts
from charmhelpers.contrib.cloudfoundry import services

from charmhelpers.contrib.cloudfoundry.upstart_helper import (
    install_upstart_scripts
)
from charmhelpers.fetch import (
    apt_install, apt_update, add_source, filter_installed_packages
)

from config import *


hooks = hookenv.Hooks()
fileproperties = {'owner': 'vcap'}

services.register([
    {
        'service': 'cf-cloudcontroller',
        'templates': [{
            'source': 'cloud_controller_ng.yml',
            'target': CC_CONFIG_FILE,
            'file_properties': fileproperties,
            'contexts': [contexts.NatsContext(),
                         contexts.RouterContext()]
        }]
    }
], os.path.join(hookenv.charm_dir(), 'templates'))


@hooks.hook("config-changed")
def config_changed():
    services.reconfigure_services()


@hooks.hook()
def stop():
    services.stop_services()


@hooks.hook('nats-relation-changed')
def nats_relation_changed():
    services.reconfigure_services()


@hooks.hook('router-relation-changed')
def router_relation_changed():
    services.reconfigure_services()


if __name__ == '__main__':
    hook_name = os.path.basename(sys.argv[0])
    log("Running {} hook".format(hook_name))
    if hookenv.relation_id():
        log("Relation {} with {}".format(
            hookenv.relation_id(), hookenv.remote_unit()))
    hooks.execute(sys.argv)
